@@ -1,3 +1,5 @@
 pub mod error;
 pub mod sizing;
-pub mod chr_display;
\ No newline at end of file
+pub mod chr_display;
+pub mod chr_gui;
+pub mod color;
\ No newline at end of file
